import {
    LayoutDashboard,
    ChevronUp,
    Boxes,
    Users,
    Globe,
    Waypoints,
    Settings,
} from "lucide-react";
import {
    DropdownMenu,
    DropdownMenuContent,
    DropdownMenuItem,
    DropdownMenuLabel,
    DropdownMenuSeparator,
    DropdownMenuTrigger,
} from "@/Components/ui/dropdown-menu";
import {
    Sidebar,
    SidebarContent,
    SidebarFooter,
    SidebarGroup,
    SidebarGroupContent,
    SidebarGroupLabel,
    SidebarMenu,
    SidebarMenuButton,
    SidebarMenuItem,
} from "@/Components/ui/sidebar";
import ResponsiveNavLink from "@/Components/ResponsiveNavLink";
import { usePage } from "@inertiajs/react";
import { router } from "@inertiajs/react";

// Menu items.
const items = [
    {
        title: "Dashboard",
        url: "/dashboard",
        icon: LayoutDashboard,
        permission: "dashboard_read",
        guard: ["web", "admin"],
    },
    {
        title: "Agency",
        url: "/agencies",
        icon: Boxes,
        permission: "agency_read",
        guard: ["admin"],
    },
    {
        title: "Users",
        url: "/users",
        icon: Users,
        permission: "user_read",
        guard: ["web"],
    },
    {
        title: "Website",
        url: "/sites",
        icon: Globe,
        permission: "website_read",
        guard: ["web"],
    },
    {
        title: "Line Item",
        url: "/lineItems",
        icon: Waypoints,
        permission: "lineitem_read",
        guard: ["web"],
    },
    {
        title: "Setting",
        url: "/settings",
        icon: Settings,
        permission: "setting_read",
        guard: ["web"],
    },
];

export function AppSidebar() {
    const { url } = usePage(); // Get the current URL
    const user = usePage().props.auth.user;
    const agency_name = usePage().props.auth.agency_name;
    const permissions = usePage().props.auth.can;
    const guard = usePage().props.auth.guard;

    // Helper function to check if the menu item is active
    // const isActive = (itemUrl: string) => {
    //     console.log(url);

    //     return url === itemUrl; // Compare current URL with the menu item's URL
    // };
     const isActive = (itemUrl: string) => {
        if (url.startsWith(itemUrl)) {
            return true; // Match if the current URL starts with the base URL of the item
        }
    };
    const navigate = (url: string) => {
        router.get(url); // Perform Inertia.js navigation
    };
    return (
        <Sidebar className="shadow-xl">
            <SidebarContent>
                <SidebarGroup>
                    <SidebarGroupLabel className="text-2xl font-bold ms-2 my-3">
                        {agency_name}
                    </SidebarGroupLabel>
                    <SidebarGroupContent>
                        <SidebarMenu>
                            {items.map((item) => (
                                <SidebarMenuItem key={item.title}>
                                    {permissions &&
                                    permissions.includes(item.permission) &&
                                    item.guard.includes(guard) ? (
                                        <SidebarMenuButton asChild isActive={isActive(item.url)}>
                                            <button
                                                onClick={() => navigate(item.url)} // Use Inertia's navigation method
                                                className={isActive(item.url) ? 'active' : ''} // Apply active class if current URL matches
                                            >
                                                <item.icon />
                                                <span>{item.title}</span>
                                            </button>
                                        </SidebarMenuButton>
                                    ) : null}
                                </SidebarMenuItem>
                            ))}
                        </SidebarMenu>
                    </SidebarGroupContent>
                </SidebarGroup>
            </SidebarContent>
            <SidebarFooter>
                <SidebarMenu>
                    <SidebarMenuItem>
                        <DropdownMenu>
                            <DropdownMenuTrigger asChild>
                                <SidebarMenuButton isActive={isActive('/profile')}>
                                    {user.name}
                                    <ChevronUp className="ml-auto" />
                                </SidebarMenuButton>
                            </DropdownMenuTrigger>
                            <DropdownMenuContent
                                side="top"
                                className="w-[--radix-popper-anchor-width]"
                            >
                                <DropdownMenuItem>
                                    <ResponsiveNavLink
                                        className="text-sm"
                                        href={route("profile.edit")}
                                    >
                                        Profile
                                    </ResponsiveNavLink>
                                </DropdownMenuItem>
                                <DropdownMenuItem>
                                    <ResponsiveNavLink
                                        method="post"
                                        href={route("logout")}
                                        as="button"
                                        className="text-sm text-red-500"
                                    >
                                        Log Out
                                    </ResponsiveNavLink>
                                </DropdownMenuItem>
                            </DropdownMenuContent>
                        </DropdownMenu>
                    </SidebarMenuItem>
                </SidebarMenu>
            </SidebarFooter>
        </Sidebar>
    );
}
